import { operatorFetch } from '../../../api/fetch';
import { IMyApp } from '../../../app';

const app = getApp<IMyApp>();
let timer = null;
// pages/components/PlatformFeeDialog/PlatformFeeDialog.js
Component({
  lifetimes: {
    attached() {
      console.log(app.globalData.userInfo);
      this.setData!({
        userInfo: app.globalData.userInfo,
      });
      this.data.eventType === 'slef' && this.fetchPlatformFee();
    },
  },
  /**
   * 组件的属性列表
   */
  properties: {
    eventType: { type: String, value: 'slef' },
  },

  /**
   * 组件的初始数据
   */
  data: {
    userInfo: app.globalData.userInfo,
    showDialog: false,
    type: 1, // 1 支付 2 扫码
    isSkip: 0,
    rechargeBalance: 0,
    payTimeLimit: 0,
    billType: '0',
    payQrUrl: '',
    countDown: 600,
    countDownString: '10分00秒',
  },

  /**
   * 组件的方法列表
   */
  methods: {
    fetchPlatformFee() {
      operatorFetch({
        url: '/operateBalance/rechage/initdata',
        method: 'POST',
        data: {
          operateId: this.data.userInfo.operateId,
          operateName: this.data.userInfo.operateName,
          position: 3,
          type: 2,
        },
      })
        .then(res => {
          const { isSkip, rechargeBalance, payTimeLimit } = res;
          this.setData({
            isSkip,
            rechargeBalance,
            payTimeLimit,
            showDialog: rechargeBalance > 0 ? true : false,
          });
        })
        .catch(err => {
          console.log(err);
        });
    },
    cancelShow() {
      this.setData({
        showDialog: false,
      });
    },
    fetchRechargeInfo() {
      console.log('in fetchRechargeInfo');
    },
    goRecordsPage() {
      wx.navigateTo({
        url: '/pages/platformFeeRecord/platformFeeRecord',
      });
    },
    toggleType() {
      let type = this.data.type;
      this.setData({
        type: type === 1 ? 2 : 1,
      });
      if (type === 1) {
        this.fetchRechargeOrderQRcode();
      } else {
        timer && clearInterval(timer);
        this.setData({
          countDown: 600,
          countDownString: '',
        });
      }
    },
    checkBillType(e) {
      console.log(e);
      const { value } = e.currentTarget.dataset;
      this.setData({
        billType: value,
      });
    },
    fetchRechargeOrderQRcode() {
      wx.showLoading({
        title: '',
      });
      const entity = {
        billType: this.data.billType,
        isAgree: 1,
        jsCode: 'string',
        operateId: this.data.userInfo.operateId,
        operateName: this.data.userInfo.operateName,
        rechargeType: '2',
        type: 2,
      };
      operatorFetch({
        url: '/operateBalance/rechage/order/formini',
        method: 'POST',
        data: entity,
      })
        .then(res => {
          wx.hideLoading();
          const { payQrUrl } = res;
          this.setData({
            payQrUrl,
          });
          timer = setInterval(() => {
            let count = this.data.countDown;
            if (count === 0) {
              clearInterval(timer);
            } else {
              let newCount = count - 1;
              let countString =
                Math.floor(newCount / 60) + '分' + (newCount % 60) + '秒';
              this.setData({
                countDown: newCount,
                countDownString: countString,
              });
            }
          }, 1000);
        })
        .catch(err => {
          wx.hideLoading();
          wx.showToast({
            title: err.msg || '请求失败',
            icon: 'none',
          });
          console.log(err);
        });
    },
  },
});
